@@ -47,8 +47,6 @@ if InternalParameters.haveKDE:
     from kde import i18n, i18nc, Sorry, Information
 else:
     # a server might not have KDE4
-    # pylint thinks those are already defined
-    # pylint: disable=E0102
     def i18n(englishIn, *args):
         """dummy for server"""
         result = englishIn
@@ -95,7 +93,7 @@ def appdataDir():
             os.makedirs(newPath)
         return newPath
     else:
-        result = os.path.dirname(str(KGlobal.dirs().locateLocal("appdata", ""))) + '/'
+        result = os.path.dirname(unicode(KGlobal.dirs().locateLocal("appdata", ""))) + '/'
         return result
 
 def cacheDir():
@@ -103,7 +101,7 @@ def cacheDir():
     if InternalParameters.isServer:
         result = os.path.join(appdataDir(), 'cache')
     else:
-        result = os.path.dirname(str(KGlobal.dirs().locateLocal("cache", "")))
+        result = os.path.dirname(unicode(KGlobal.dirs().locateLocal("cache", "")))
         result = os.path.join(result, 'kajongg')
     if not os.path.exists(result):
         os.makedirs(result)
